{% load rapid_prototyping_tags %}
<tr>
    <td colspan="2"><strong>Total</strong></td>
    <td><strong><span class="costsTimeTotal"></span></strong></td>
    <td></td>
    <td><strong><span class="costsCostsTotal"></span></strong></td>
    <td></td>
    <td><strong><span class="costsDeveloperTimeTotal"></span></strong></td>
    <td><strong><span class="costsDeveloperCostsTotal"></span></strong></td>
    <td><strong><span class="costsActualTimeTotal"></span></strong></td>
    <td><strong><span class="costsActualCostsTotal"></span></strong></td>
    <td><strong><span class="costsDeveloperDifferenceTotal"></span> (<span class="costsEstimatedDifferenceTotal"></span>)</strong></td>
</tr>
