<thead>
    {% if not hide_caption == 1 %}
        <caption><p><strong>Estimated Costs</strong></p></caption>
    {% endif %}
    <tr>
        <th>ID</th>
        <th>Task</th>
        <th>Estimated Time</th>
        <th>Rate</th>
        <th>Estimated Costs</th>
        <th>Sprint ID</th>
        <th>Developer Estimated Time</th>
        <th>Developer Estimated Cost</th>
        <th>Actual Time</th>
        <th>Actual Cost</th>
        <th data-toggle="tooltip" title="Difference to Developer Estimated Time (Difference to Estimated Time)">Difference</th>
    </tr>
</thead>
