{% load rapid_prototyping_tags %}

{% for item in costs %}
{% get_hourly_rate item.rate as hourly_rate %}
<tr>
    <td>
        {% if item.link %}
            <a href="{{ item.link }}">{{ item.id }}</a>
        {% else %}
            {{ item.id }}
        {% endif %}
    </td>

    {% if item.external_link %}
        <td><a href="{{ item.external_link }}" target="_blank">{{ item.task }}</a></td>
    {% else %}
        <td>{{ item.task }}</td>
    {% endif %}

    <td><span class="costsTime">{{ item.time }}</span></td>
    <td><span>{{ hourly_rate }}</span></td>
    <td><span class="costsCosts">{{ item.time|calculate_costs:hourly_rate }}</span></td>

    <td>{{ item.sprint }}</td>

    {% if item.developer_time %}
        <td><span class="costsDeveloperTime">{{ item.developer_time }}</span></td>
        <td><span class="costsDeveloperCosts">{{ item.developer_time|calculate_costs:hourly_rate }}</span></td>
    {% else %}
        <td></td>
        <td></td>
    {% endif %}

    {% if item.actual_time %}
        <td><span class="costsActualTime">{{ item.actual_time }}</span></td>
        <td><span class="costsActualCosts">{{ item.actual_time|calculate_costs:hourly_rate }}</span></td>
        <td><span class="costsDeveloperDifference">{% get_difference item.developer_time item.actual_time %}</span> <span class="costsEstimatedDifference">({% get_difference item.time item.actual_time %})</span></td>
    {% else %}
        <td></td>
        <td></td>
        <td></td>
    {% endif %}
</tr>
{% endfor %}
