{% load libs_tags rapid_prototyping_tags %}
<table class="table table-bordered table-hover">
    {% include "rapid_prototyping/costs_table_head.html" %}
    <tbody>
        {% include "rapid_prototyping/costs_table_body.html" %}
        {% include "rapid_prototyping/costs_total.html" %}
    </tbody>
</table>
<p class="text-center"><a href="/p/p_index.html">Index</a></p>
